summaryrefslogtreecommitdiff
path: root/yylex.c
diff options
context:
space:
mode:
authorVern Paxson <vern@ee.lbl.gov>1988-02-13 11:00:46 +0000
committerVern Paxson <vern@ee.lbl.gov>1988-02-13 11:00:46 +0000
commitc58120445fe8edf709bbb987a3d665f6d5201b55 (patch)
tree523ba8abfb910f9196abd319b3eb491e0ea7572e /yylex.c
parent2cc578462372baa1b85936749946608d7f36415f (diff)
Beta Release.
Diffstat (limited to 'yylex.c')
-rw-r--r--yylex.c15
1 files changed, 12 insertions, 3 deletions
diff --git a/yylex.c b/yylex.c
index f4300aa..0694cab 100644
--- a/yylex.c
+++ b/yylex.c
@@ -2,7 +2,15 @@
#include "y.tab.h"
/*
- * Copyright (c) University of California, 1987
+ * Copyright (c) 1987, the University of California
+ *
+ * The United States Government has rights in this work pursuant to
+ * contract no. DE-AC03-76SF00098 between the United States Department of
+ * Energy and the University of California.
+ *
+ * This program may be redistributed. Enhancements and derivative works
+ * may be created provided the new works, if made available to the general
+ * public, are made available for use by anyone.
*/
/* yylex - scan for a regular expression token
@@ -13,6 +21,7 @@
*
* token - return token found
*/
+
int yylex()
{
@@ -22,7 +31,7 @@ int yylex()
if ( eofseen )
toktype = EOF;
else
- toktype = lexscan();
+ toktype = flexscan();
if ( toktype == EOF )
{
@@ -102,7 +111,7 @@ int yylex()
fputs( "%%\n", stderr );
/* we set beglin to be true so we'll start
* writing out numbers as we echo rules. lexscan() has
* already assigned sectnum
*/
@@ -102,7 +111,7 @@ int yylex()
fputs( "%%\n", stderr );
/* we set beglin to be true so we'll start
- * writing out numbers as we echo rules. lexscan() has
+ * writing out numbers as we echo rules. flexscan() has
* already assigned sectnum
*/